@@ -1,11 +1,11 @@
 
-/* Generated data (by glib-mkenums) */
+
 
 #undef GTK_DISABLE_DEPRECATED
 #define GTK_ENABLE_BROKEN
 #include <exo-helper/exo-helper.h>
-#include <exo-helper/exo-helper-enum-types.h>
 
+#include "exo-helper-enum-types.h"
 
 /* enumerations from "exo-helper.h" */
 GType
@@ -16,6 +16,7 @@ exo_helper_category_get_type (void)
 	static const GEnumValue values[] = {
 	{ EXO_HELPER_WEBBROWSER, "EXO_HELPER_WEBBROWSER", "WebBrowser" },
 	{ EXO_HELPER_MAILREADER, "EXO_HELPER_MAILREADER", "MailReader" },
+	{ EXO_HELPER_FILEMANAGER, "EXO_HELPER_FILEMANAGER", "FileManager" },
 	{ EXO_HELPER_TERMINALEMULATOR, "EXO_HELPER_TERMINALEMULATOR", "TerminalEmulator" },
 	{ 0, NULL, NULL }
 	};
@@ -24,5 +25,5 @@ exo_helper_category_get_type (void)
 	return type;
 }
 
-/* Generated data ends here */
+
 
